pub struct ErrorContext {
pub input: String,
pub backend: String,
pub config: Option<String>,
pub stack_trace: Option<Vec<String>>,
}Expand description
Error context for providing additional information about parsing failures
Fields
input: StringInput text that was being parsed
backend: StringCurrent parser backend
config: Option<String>Parser configuration at time of error
stack_trace: Option<Vec<String>>Stack trace or call stack if available
Implementations
Sourceimpl ErrorContext
impl ErrorContext
Sourcepub fn with_config(self, config: String) -> Self
pub fn with_config(self, config: String) -> Self
Add configuration information
Sourcepub fn with_stack_trace(self, stack_trace: Vec<String>) -> Self
pub fn with_stack_trace(self, stack_trace: Vec<String>) -> Self
Add stack trace information
Sourcepub fn get_error_snippet(
&self,
position: &SourcePosition,
context_lines: usize,
) -> String
pub fn get_error_snippet( &self, position: &SourcePosition, context_lines: usize, ) -> String
Get a snippet of the input around the error position