pub fn reset()Expand description
Clear the recorded access path. Tests call this before a query so a stale value from a previous query cannot satisfy the assertion.
pub fn reset()Clear the recorded access path. Tests call this before a query so a stale value from a previous query cannot satisfy the assertion.