pub struct ByteComparableEncoder { /* private fields */ }Expand description
CEP-25 compliant byte-comparable key encoder
Implements the byte-comparable key encoding as specified in CEP-25. The encoding ensures that lexicographic comparison of the encoded bytes produces the same ordering as the typed comparison of the original values.
Implementations
Sourceimpl ByteComparableEncoder
impl ByteComparableEncoder
Sourcepub fn with_config(config: EncoderConfig) -> Self
pub fn with_config(config: EncoderConfig) -> Self
Create new encoder with custom configuration
Sourcepub fn config(&self) -> &EncoderConfig
pub fn config(&self) -> &EncoderConfig
Get current configuration
Sourcepub fn set_config(&mut self, config: EncoderConfig)
pub fn set_config(&mut self, config: EncoderConfig)
Set new configuration