PartitionTombstone

Struct PartitionTombstone 

pub struct PartitionTombstone {
    pub deletion_time: i64,
    pub local_deletion_time: i32,
}
Partition tombstone for deleting entire partition

Stored in the partition header and shadows all rows in the partition when the partition deletion time is greater than the row timestamps.

Fields

deletion_time: i64

Deletion timestamp in microseconds since Unix epoch

local_deletion_time: i32

Local deletion time in seconds since Unix epoch