pub struct RangeTombstone {
pub start: ClusteringBound,
pub end: ClusteringBound,
pub deletion_time: i64,
pub local_deletion_time: i32,
}Expand description
Range tombstone for deleting a range of clustering keys
Stored as markers within the partition data and shadows all rows in the specified clustering key range.
Fields
start: ClusteringBoundStart bound (inclusive or exclusive)
end: ClusteringBoundEnd bound (inclusive or exclusive)
deletion_time: i64Deletion timestamp in microseconds since Unix epoch
local_deletion_time: i32Local deletion time in seconds since Unix epoch