Schema definition and parsing for CQLite
This module handles schema definitions that describe the structure of Cassandra tables for schema-aware SSTable reading. It supports both JSON-based schema definitions and CQL CREATE TABLE statement parsing.
Re-exports
pub use aggregator::AggregatorConfig;pub use aggregator::LoadErrorType;pub use aggregator::LoadResult;pub use aggregator::SchemaAggregator;pub use aggregator::SchemaLoadError;pub use aggregator::SchemaLoadWarning;pub use cql_parser::cql_type_to_type_id;pub use cql_parser::extract_table_name;pub use cql_parser::parse_cql_schema;pub use cql_parser::parse_cql_schema_with_visitor;pub use cql_parser::parse_create_table;pub use cql_parser::table_name_matches;pub use discovery::ColumnDefinition;pub use discovery::DiscoveryMethod;pub use discovery::IndexDefinition;pub use discovery::SchemaDiscoveryConfig;pub use discovery::SchemaDiscoveryEngine;pub use discovery::SchemaInfo;pub use discovery::SchemaMetadata;pub use discovery::TableOptions;pub use discovery::TypeInfo;pub use discovery::UDTDefinition;pub use discovery::ValidationError;pub use discovery::ValidationResults;pub use discovery::ValidationStatus;pub use discovery::ValidationWarning;pub use registry::ParsingContext;pub use registry::RegistryStatistics;pub use registry::SchemaChange;pub use registry::SchemaChangeType;pub use registry::SchemaQuery;pub use registry::SchemaRegistry;pub use registry::SchemaRegistryConfig;pub use registry::SchemaSource;pub use registry::SchemaValidationStatus;pub use registry::SchemaValidator;pub use registry::SchemaVersion;pub use registry::ValidationReport;pub use parser::SchemaParser;
Modules
- aggregator
- Schema Aggregator for M2-CLI
- cql_
parser - CQL Schema Parser
- discovery
- Comprehensive Schema Discovery and Validation System
- parser
- Schema-driven parser for CQLite
- registry
- Schema Registry for Centralized Schema Management
Structs
- Clustering
Column - Clustering key column with ordering
- Column
- Regular column definition
- KeyColumn
- Partition key column definition
- Schema
Manager - Schema management service for handling table schemas and UDT definitions
- Table
Schema - Table schema definition loaded from JSON
- UdtRegistry
- UDT Schema Registry for managing User Defined Type definitions
Enums
- Clustering
Order - Clustering order enum for sorting
- CqlType
- Parsed CQL data type